@@ -53,9 +53,9 @@ class ReadIOException(ReadException):
     pass
 
 
-class ReadExceptionGroup(ExceptionGroup, ReadIOException):
+class ReadExceptionGroup(ExceptionGroup, ReadException):
     def __str__(self) -> str:
-        messages = ", ".join(str(exception) for exception in self._exceptions)
+        messages = ", ".join(str(exception) for exception in self.exceptions)
         return f"{self.message} ({messages})"
 
 
